========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/blazar-dashboard.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

================
Blazar dashboard
================

Horizon plugin for the Blazar Reservation Service for OpenStack

Features
--------

See doc/source/index.rst

Enabling in DevStack
--------------------

Not yet supported

Manual Installation
-------------------

See doc/source/install.rst

Other Resources
---------------

* Source code:

  * `Blazar <https://opendev.org/openstack/blazar>`__
  * `Nova scheduler filter <https://opendev.org/openstack/blazar-nova>`__
  * `Client tools <https://opendev.org/openstack/python-blazarclient>`__
  * `Dashboard (Horizon plugin) <https://opendev.org/openstack/blazar-dashboard>`__

* Blueprints/Bugs: https://launchpad.net/blazar
* Documentation: https://docs.openstack.org/blazar/latest/
* Release notes: https://docs.openstack.org/releasenotes/blazar-dashboard
